<?php
/**
 * ReduxFramework Sample Config File
 * For full documentation, please visit: http://docs.reduxframework.com/
 */

if (!class_exists('Apuslisting_Redux_Framework_Config')) {

    class Apuslisting_Redux_Framework_Config
    {
        public $args = array();
        public $sections = array();
        public $theme;
        public $ReduxFramework;

        public function __construct()
        {
            if (!class_exists('ReduxFramework')) {
                return;
            }
            add_action('init', array($this, 'initSettings'), 10);
        }

        public function initSettings()
        {
            // Just for demo purposes. Not needed per say.
            $this->theme = wp_get_theme();

            // Set the default arguments
            $this->setArguments();

            // Create the sections and fields
            $this->setSections();

            if (!isset($this->args['opt_name'])) { // No errors please
                return;
            }

            $this->ReduxFramework = new ReduxFramework($this->sections, $this->args);
        }

        public function setSections()
        {
            global $wp_registered_sidebars;
            $sidebars = array();

            if ( !empty($wp_registered_sidebars) ) {
                foreach ($wp_registered_sidebars as $sidebar) {
                    $sidebars[$sidebar['id']] = $sidebar['name'];
                }
            }
            $columns = array( '1' => esc_html__('1 Column', 'apuslisting'),
                '2' => esc_html__('2 Columns', 'apuslisting'),
                '3' => esc_html__('3 Columns', 'apuslisting'),
                '4' => esc_html__('4 Columns', 'apuslisting'),
                '6' => esc_html__('6 Columns', 'apuslisting')
            );
            
            $general_fields = array();
            if ( !function_exists( 'wp_site_icon' ) ) {
                $general_fields[] = array(
                    'id' => 'media-favicon',
                    'type' => 'media',
                    'title' => esc_html__('Favicon Upload', 'apuslisting'),
                    'desc' => esc_html__('', 'apuslisting'),
                    'subtitle' => esc_html__('Upload a 16px x 16px .png or .gif image that will be your favicon.', 'apuslisting'),
                );
            }
            $general_fields[] = array(
                'id' => 'is_boxed',
                'type' => 'switch',
                'title' => esc_html__('Is Boxed', 'apuslisting'),
                'subtitle' => esc_html__('Boxed is not support for Listing Half Map and Listing detail Half Map layout', 'apuslisting'),
                'default' => false,
            );
            $general_fields[] = array(
                'id' => 'preload',
                'type' => 'switch',
                'title' => esc_html__('Preload Website', 'apuslisting'),
                'default' => true,
            );
            $general_fields[] = array(
                'id' => 'image_lazy_loading',
                'type' => 'switch',
                'title' => esc_html__('Show Image lazy Loading', 'apuslisting'),
                'default' => true,
            );
            // General Settings Tab
            $this->sections[] = array(
                'icon' => 'el-icon-cogs',
                'title' => esc_html__('General', 'apuslisting'),
                'fields' => $general_fields
            );
            // Header
            $this->sections[] = array(
                'icon' => 'el el-website',
                'title' => esc_html__('Header', 'apuslisting'),
                'fields' => array(
                    array(
                        'id' => 'media-logo',
                        'type' => 'media',
                        'title' => esc_html__('Logo Upload', 'apuslisting'),
                        'subtitle' => esc_html__('Upload a .png or .gif image that will be your logo.', 'apuslisting'),
                    ),
                    array(
                        'id' => 'media-mobile-logo',
                        'type' => 'media',
                        'title' => esc_html__('Mobile Logo Upload', 'apuslisting'),
                        'subtitle' => esc_html__('Upload a .png or .gif image that will be your logo.', 'apuslisting'),
                    ),
                    array(
                        'id' => 'header_type',
                        'type' => 'select',
                        'title' => esc_html__('Header Layout Type', 'apuslisting'),
                        'subtitle' => esc_html__('Choose a header for your website.', 'apuslisting'),
                        'options' => apuslisting_get_header_layouts()
                    ),
                    array(
                        'id' => 'keep_header',
                        'type' => 'switch',
                        'title' => esc_html__('Stick Header', 'apuslisting'),
                        'default' => false
                    ),
                    array(
                        'id' => 'show_login_register',
                        'type' => 'switch',
                        'title' => esc_html__('Show Login/Register', 'apuslisting'),
                        'default' => true
                    ),
                    array(
                        'id' => 'show_add_listing',
                        'type' => 'select',
                        'title' => esc_html__('Show Add Listing Button', 'apuslisting'),
                        'options' => array(
                            'no' => esc_html__('No', 'apuslisting'),
                            'always' => esc_html__('Always', 'apuslisting'),
                            'show_logedin' => esc_html__('Logedin user', 'apuslisting'),
                        ),
                        'default' => 'always',
                        'subtitle' => wp_kses(sprintf(__('Go to <a href="%s">Listings Settings</a> > Pages tab to setting Submit Job Page', 'apuslisting'), admin_url( 'edit.php?post_type=job_listing&page=job-manager-settings')), array('a' => array('href' => array()))),
                    )
                )
            );
            // Footer
            $this->sections[] = array(
                'icon' => 'el el-website',
                'title' => esc_html__('Footer', 'apuslisting'),
                'fields' => array(
                    array(
                        'id' => 'footer_type',
                        'type' => 'select',
                        'title' => esc_html__('Footer Layout Type', 'apuslisting'),
                        'subtitle' => esc_html__('Choose a footer for your website.', 'apuslisting'),
                        'options' => apuslisting_get_footer_layouts()
                    ),
                    array(
                        'id' => 'back_to_top',
                        'type' => 'switch',
                        'title' => esc_html__('Back To Top Button', 'apuslisting'),
                        'subtitle' => esc_html__('Toggle whether or not to enable a back to top button on your pages.', 'apuslisting'),
                        'default' => true,
                    ),
                )
            );

            // Blog settings
            $this->sections[] = array(
                'icon' => 'el el-pencil',
                'title' => esc_html__('Blog', 'apuslisting'),
                'fields' => array(
                    array(
                        'id' => 'show_blog_breadcrumbs',
                        'type' => 'switch',
                        'title' => esc_html__('Breadcrumbs', 'apuslisting'),
                        'default' => 1
                    ),
                    array (
                        'title' => esc_html__('Breadcrumbs Background Color', 'apuslisting'),
                        'subtitle' => '<em>'.esc_html__('The breadcrumbs background color of the site.', 'apuslisting').'</em>',
                        'id' => 'blog_breadcrumb_color',
                        'type' => 'color',
                        'transparent' => false,
                    ),
                    array(
                        'id' => 'blog_breadcrumb_image',
                        'type' => 'media',
                        'title' => esc_html__('Breadcrumbs Background', 'apuslisting'),
                        'subtitle' => esc_html__('Upload a .jpg or .png image that will be your breadcrumbs.', 'apuslisting'),
                    ),
                )
            );
            // Archive Blogs settings
            $this->sections[] = array(
                'subsection' => true,
                'title' => esc_html__('Blog & Post Archives', 'apuslisting'),
                'fields' => array(
                    array(
                        'id' => 'blog_archive_layout',
                        'type' => 'image_select',
                        'compiler' => true,
                        'title' => esc_html__('Layout', 'apuslisting'),
                        'subtitle' => esc_html__('Select the variation you want to apply on your store.', 'apuslisting'),
                        'options' => array(
                            'main' => array(
                                'title' => esc_html__('Main Only', 'apuslisting'),
                                'alt' => esc_html__('Main Only', 'apuslisting'),
                                'img' => get_template_directory_uri() . '/inc/assets/images/screen1.png'
                            ),
                            'left-main' => array(
                                'title' => esc_html__('Left - Main Sidebar', 'apuslisting'),
                                'alt' => esc_html__('Left - Main Sidebar', 'apuslisting'),
                                'img' => get_template_directory_uri() . '/inc/assets/images/screen2.png'
                            ),
                            'main-right' => array(
                                'title' => esc_html__('Main - Right Sidebar', 'apuslisting'),
                                'alt' => esc_html__('Main - Right Sidebar', 'apuslisting'),
                                'img' => get_template_directory_uri() . '/inc/assets/images/screen3.png'
                            ),
                            'left-main-right' => array(
                                'title' => esc_html__('Left - Main - Right Sidebar', 'apuslisting'),
                                'alt' => esc_html__('Left - Main - Right Sidebar', 'apuslisting'),
                                'img' => get_template_directory_uri() . '/inc/assets/images/screen4.png'
                            ),
                        ),
                        'default' => 'main'
                    ),
                    array(
                        'id' => 'blog_archive_fullwidth',
                        'type' => 'switch',
                        'title' => esc_html__('Is Full Width?', 'apuslisting'),
                        'default' => false
                    ),
                    array(
                        'id' => 'blog_archive_left_sidebar',
                        'type' => 'select',
                        'title' => esc_html__('Archive Left Sidebar', 'apuslisting'),
                        'subtitle' => esc_html__('Choose a sidebar for left sidebar.', 'apuslisting'),
                        'options' => $sidebars
                    ),
                    array(
                        'id' => 'blog_archive_right_sidebar',
                        'type' => 'select',
                        'title' => esc_html__('Archive Right Sidebar', 'apuslisting'),
                        'subtitle' => esc_html__('Choose a sidebar for right sidebar.', 'apuslisting'),
                        'options' => $sidebars
                        
                    ),
                    array(
                        'id' => 'blog_display_mode',
                        'type' => 'select',
                        'title' => esc_html__('Display Mode', 'apuslisting'),
                        'options' => array(
                            'grid' => esc_html__('Grid Layout', 'apuslisting'),
                            'list' => esc_html__('List Layout', 'apuslisting'),
                            'mansory' => esc_html__('Mansory', 'apuslisting'),
                        ),
                        'default' => 'grid'
                    ),
                    array(
                        'id' => 'blog_columns',
                        'type' => 'select',
                        'title' => esc_html__('Blog Columns', 'apuslisting'),
                        'options' => $columns,
                        'default' => 4
                    ),
                    array(
                        'id' => 'blog_item_thumbsize',
                        'type' => 'text',
                        'title' => esc_html__('Thumbnail Size', 'apuslisting'),
                        'subtitle' => esc_html__('This featured for the site is using Visual Composer.', 'apuslisting'),
                        'desc' => esc_html__('Enter thumbnail size. Example: thumbnail, medium, large, full or other sizes defined by current theme. Alternatively enter image size in pixels: 200x100 (Width x Height) .', 'apuslisting'),
                    ),
                )
            );
            // Single Blogs settings
            $this->sections[] = array(
                'subsection' => true,
                'title' => esc_html__('Blog', 'apuslisting'),
                'fields' => array(
                    
                    array(
                        'id' => 'show_blog_social_share',
                        'type' => 'switch',
                        'title' => esc_html__('Show Social Share', 'apuslisting'),
                        'default' => 1
                    ),
                    array(
                        'id' => 'show_blog_releated',
                        'type' => 'switch',
                        'title' => esc_html__('Show Releated Posts', 'apuslisting'),
                        'default' => 1
                    ),
                    array(
                        'id' => 'number_blog_releated',
                        'type' => 'text',
                        'title' => esc_html__('Number of related posts to show', 'apuslisting'),
                        'required' => array('show_blog_releated', '=', '1'),
                        'default' => 4,
                        'min' => '1',
                        'step' => '1',
                        'max' => '20',
                        'type' => 'slider'
                    ),
                    array(
                        'id' => 'releated_blog_columns',
                        'type' => 'select',
                        'title' => esc_html__('Releated Blogs Columns', 'apuslisting'),
                        'required' => array('show_blog_releated', '=', '1'),
                        'options' => $columns,
                        'default' => 4
                    ),

                )
            );
            $pages = array();
            if (is_admin()) {
                $args = array(
                    'posts_per_page'   => -1,
                    'offset'           => 0,
                    'orderby'          => 'date',
                    'order'            => 'DESC',
                    'post_type'        => 'page',
                    'post_status'      => 'publish',
                    'suppress_filters' => true 
                );
                $posts = get_posts( $args );
                foreach ( $posts as $post ) {
                    $pages[$post->post_name] = $post->post_title;
                }
            }
            // Archive Listings settings
            $this->sections[] = array(
                'title' => esc_html__('Listing Archives', 'apuslisting'),
                'fields' => array(
                    array(
                        'id' => 'listing_archive_layout_version',
                        'type' => 'select',
                        'title' => esc_html__('Layout Type', 'apuslisting'),
                        'options' => array(
                            'default' => esc_html__('Default', 'apuslisting'),
                            'half-map' => esc_html__('Half Map', 'apuslisting'),
                        ),
                        'default' => 'half-map'
                    ),
                    
                    array(
                        'id' => 'listing_archive_display_mode',
                        'type' => 'select',
                        'title' => esc_html__('Default Display Mode', 'apuslisting'),
                        'options' => array(
                            'grid' => esc_html__('Grid', 'apuslisting'),
                            'list' => esc_html__('List', 'apuslisting'),
                        ),
                        'default' => 'grid'
                    ),
                    array(
                        'id' => 'listing_columns',
                        'type' => 'select',
                        'title' => esc_html__('Grid Listing Columns', 'apuslisting'),
                        'options' => $columns,
                        'default' => 2,
                        'required' => array('listing_archive_display_mode', '=', 'grid'),
                    ),
                    array (
                        'id' => 'archive_breadcrumbs_settings',
                        'icon' => true,
                        'type' => 'info',
                        'raw' => '<h3 style="margin: 0;"> '.esc_html__('Breadcrumbs Settings', 'apuslisting').'</h3>',
                        'required' => array('listing_archive_layout_version', '=', array('default' )),
                    ),
                    array(
                        'id' => 'show_listing_breadcrumbs',
                        'type' => 'switch',
                        'title' => esc_html__('Breadcrumbs', 'apuslisting'),
                        'default' => 1,
                        'description' => esc_html__('Breadcrumb is only apply for Listing Archives version (List, Grid)', 'apuslisting'),
                        'required' => array('listing_archive_layout_version', '=', array('default' )),
                    ),
                    array (
                        'title' => esc_html__('Breadcrumbs Background Color', 'apuslisting'),
                        'subtitle' => '<em>'.esc_html__('The breadcrumbs background color of the site.', 'apuslisting').'</em>',
                        'id' => 'listing_breadcrumb_color',
                        'type' => 'color',
                        'transparent' => false,
                        'required' => array('listing_archive_layout_version', '=', array('default' )),
                    ),
                    array(
                        'id' => 'listing_breadcrumb_image',
                        'type' => 'media',
                        'title' => esc_html__('Breadcrumbs Background', 'apuslisting'),
                        'subtitle' => esc_html__('Upload a .jpg or .png image that will be your breadcrumbs.', 'apuslisting'),
                        'required' => array('listing_archive_layout_version', '=', array('default' )),
                    ),
                    
                    array (
                        'id' => 'sidebar_position',
                        'icon' => true,
                        'type' => 'info',
                        'raw' => '<h3 style="margin: 0;"> '.esc_html__('Sidebar Position', 'apuslisting').'</h3>',
                        'required' => array('listing_archive_layout_version', '=', array('default')),
                    ),
                    array(
                        'id' => 'listing_archive_layout',
                        'type' => 'image_select',
                        'compiler' => true,
                        'title' => esc_html__('Sidebar Layout', 'apuslisting'),
                        'subtitle' => esc_html__('Select a sidebar layout', 'apuslisting'),
                        'options' => array(
                            'main' => array(
                                'title' => esc_html__('Main Content', 'apuslisting'),
                                'alt' => esc_html__('Main Content', 'apuslisting'),
                                'img' => get_template_directory_uri() . '/inc/assets/images/screen1.png'
                            ),
                            'left-main' => array(
                                'title' => esc_html__('Left - Main Sidebar', 'apuslisting'),
                                'alt' => esc_html__('Left - Main Sidebar', 'apuslisting'),
                                'img' => get_template_directory_uri() . '/inc/assets/images/screen2.png'
                            ),
                            'main-right' => array(
                                'title' => esc_html__('Main - Right Sidebar', 'apuslisting'),
                                'alt' => esc_html__('Main - Right Sidebar', 'apuslisting'),
                                'img' => get_template_directory_uri() . '/inc/assets/images/screen3.png'
                            ),
                        ),
                        'default' => 'left-main',
                        'required' => array('listing_archive_layout_version', '=', array('default')),
                    ),
                    array(
                        'id' => 'listing_archive_sidebar',
                        'type' => 'select',
                        'title' => esc_html__('Listings Sidebar', 'apuslisting'),
                        'subtitle' => esc_html__('Choose a sidebar for listings sidebar.', 'apuslisting'),
                        'options' => $sidebars,
                        'default' => 'listing-archive-sidebar',
                        'required' => array('listing_archive_layout_version', '=', array('default')),
                    ),
                )
            );
            $this->sections[] = array(
                'subsection' => true,
                'title' => esc_html__('Filter Settings', 'apuslisting'),
                'fields' => array(
                    array(
                        'id' => 'listing_filter_type',
                        'type' => 'select',
                        'title' => esc_html__('Filter Type', 'apuslisting'),
                        'options' => array(
                            'location' => esc_html__('Filter By Location', 'apuslisting'),
                            'region' => esc_html__('Filter By Region', 'apuslisting'),
                        )
                    ),
                    array(
                        'id' => 'listing_filter_show_keyword',
                        'type' => 'switch',
                        'title' => esc_html__('Show keyword field', 'apuslisting'),
                        'default' => 1,
                    ),
                    array(
                        'id' => 'listing_filter_show_price',
                        'type' => 'switch',
                        'title' => esc_html__('Show price field', 'apuslisting'),
                        'default' => 1,
                    ),
                    array(
                        'id' => 'listing_filter_show_categories',
                        'type' => 'switch',
                        'title' => esc_html__('Show categories field', 'apuslisting'),
                        'default' => 1,
                    ),
                    array(
                        'id' => 'listing_filter_show_regions',
                        'type' => 'switch',
                        'title' => esc_html__('Show regions field', 'apuslisting'),
                        'default' => 1,
                        'required' => array('listing_filter_type', '=', array('region')),
                    ),
                    array(
                        'id' => 'listing_filter_show_location',
                        'type' => 'switch',
                        'title' => esc_html__('Show location field', 'apuslisting'),
                        'default' => 1,
                        'required' => array('listing_filter_type', '=', array('location')),
                    ),
                    array(
                        'id' => 'listing_filter_show_distance',
                        'type' => 'switch',
                        'title' => esc_html__('Show distance field', 'apuslisting'),
                        'default' => 1,
                        'required' => array('listing_filter_type', '=', array('location')),
                    ),
                    array(
                        'id' => 'listing_filter_distance_default',
                        'type' => 'text',
                        'title' => esc_html__('Distance default', 'apuslisting'),
                        'default' => 50,
                        'required' => array('listing_filter_type', '=', array('location')),
                    ),
                    array(
                        'id' => 'listing_filter_distance_type',
                        'type' => 'select',
                        'title' => esc_html__('Show distance field', 'apuslisting'),
                        'options' => array(
                            'km' => esc_html__('Kilometre', 'apuslisting'),
                            'miles' => esc_html__('Miles', 'apuslisting'),
                        ),
                        'default' => 'km',
                        'required' => array('listing_filter_type', '=', array('location')),
                    ),
                    array(
                        'id' => 'listing_filter_show_amenieties',
                        'type' => 'select',
                        'title' => esc_html__('Show amenieties fields', 'apuslisting'),
                        'options' => array(
                            '' => esc_html__('Hidden', 'apuslisting'),
                            'show' => esc_html__('Show', 'apuslisting'),
                            'more-filter' => esc_html__('Show when click more filter button', 'apuslisting'),
                        ),
                        'default' => 'more-filter'
                    ),
                )
            );
            // Single Listing settings
            $this->sections[] = array(
                'title' => esc_html__('Listing Detail', 'apuslisting'),
                'fields' => array(
                    array(
                        'id' => 'listing_single_layout_version',
                        'type' => 'select',
                        'title' => esc_html__('Layout Type', 'apuslisting'),
                        'options' => array(
                            'v1' => esc_html__('Version 1', 'apuslisting'),
                            'v2' => esc_html__('Version 2', 'apuslisting'),
                        ),
                        'default' => 'v1'
                    ),
                    array(
                        'id'        => 'listing_single_sort_content',
                        'type'      => 'sorter',
                        'title'     => esc_html__( 'Listing Content', 'apuslisting' ),
                        'subtitle'  => esc_html__( 'Please drag and arrange the block', 'apuslisting' ),
                        'options'   => array(
                            'enabled' => apply_filters( 'apuslisting_listing_single_sort_content', array(
                                'description' => esc_html__( 'Description', 'apuslisting' ),
                                'video' => esc_html__( 'Video', 'apuslisting' ),
                                'amenities' => esc_html__( 'Amenities', 'apuslisting' ),
                                'hours' => esc_html__( 'Hours', 'apuslisting' ),
                                'maps' => esc_html__( 'Maps', 'apuslisting' ),
                                'contact' => esc_html__( 'Contact', 'apuslisting' ),
                                'comments' => esc_html__( 'Reviews', 'apuslisting' ),
                            )),
                            'disabled' => array()
                        )
                    ),
                    array(
                        'id'        => 'listing_single_sort_sidebar',
                        'type'      => 'sorter',
                        'title'     => esc_html__( 'Listing Sidebar', 'apuslisting' ),
                        'subtitle'  => esc_html__( 'Please drag and arrange the block', 'apuslisting' ),
                        'options'   => array(
                            'enabled' => apply_filters( 'apuslisting_listing_single_sort_sidebar', array(
                                'maps-contact' => esc_html__( 'Maps - Contact Info', 'apuslisting' ),
                                'amenities' => esc_html__( 'Amenities', 'apuslisting' ),
                                'hours' => esc_html__( 'Hours', 'apuslisting' ),
                                'nearby' => esc_html__( 'Nearby Places', 'apuslisting' ),
                                'nearby_browse' => esc_html__( 'Browse Nearby Places', 'apuslisting' ),
                                'price_range' => esc_html__( 'Price Range', 'apuslisting' ),
                            )),
                            'disabled' => array()
                        )
                    ),
                    array(
                        'id' => 'show_listing_social_share',
                        'type' => 'switch',
                        'title' => esc_html__('Show Social Share', 'apuslisting'),
                        'default' => 1
                    ),
                    array (
                        'id' => 'single_breadcrumbs_settings',
                        'icon' => true,
                        'type' => 'info',
                        'raw' => '<h3 style="margin: 0;"> '.esc_html__('Breadcrumbs Settings', 'apuslisting').'</h3>',
                    ),
                    array(
                        'id' => 'show_single_listing_breadcrumbs',
                        'type' => 'switch',
                        'title' => esc_html__('Breadcrumbs', 'apuslisting'),
                        'default' => 1
                    ),
                    array (
                        'id' => 'single_sidebar_position',
                        'icon' => true,
                        'type' => 'info',
                        'raw' => '<h3 style="margin: 0;"> '.esc_html__('Sidebar Position', 'apuslisting').'</h3>',
                    ),
                    array(
                        'id' => 'listing_single_layout',
                        'type' => 'image_select',
                        'compiler' => true,
                        'title' => esc_html__('Sidebar Layout', 'apuslisting'),
                        'subtitle' => esc_html__('Select a sidebar layout', 'apuslisting'),
                        'options' => array(
                            'left-main' => array(
                                'title' => esc_html__('Left - Main Sidebar', 'apuslisting'),
                                'alt' => esc_html__('Left - Main Sidebar', 'apuslisting'),
                                'img' => get_template_directory_uri() . '/inc/assets/images/screen2.png'
                            ),
                            'main-right' => array(
                                'title' => esc_html__('Main - Right Sidebar', 'apuslisting'),
                                'alt' => esc_html__('Main - Right Sidebar', 'apuslisting'),
                                'img' => get_template_directory_uri() . '/inc/assets/images/screen3.png'
                            ),
                        ),
                        'default' => 'left-main',
                    ),
                    array(
                        'id' => 'listing_single_sidebar',
                        'type' => 'select',
                        'title' => esc_html__('Listings Sidebar', 'apuslisting'),
                        'subtitle' => esc_html__('Choose a sidebar for listings sidebar.', 'apuslisting'),
                        'options' => $sidebars,
                    )

                )
            );
            // Listing Map Settings
            $this->sections[] = array(
                'subsection' => true,
                'title' => esc_html__('Listing Review Settings', 'apuslisting'),
                'fields' => array(
                    array(
                        'id' => 'listing_review_enable_upload_photos',
                        'type' => 'switch',
                        'title' => esc_html__('Enable upload photos', 'apuslisting'),
                        'default' => 1
                    ),
                    array(
                        'id' => 'listing_review_enable_like',
                        'type' => 'switch',
                        'title' => esc_html__('Enable like review', 'apuslisting'),
                        'default' => 1
                    ),
                    array(
                        'id' => 'listing_review_enable_reply',
                        'type' => 'switch',
                        'title' => esc_html__('Enable reply review', 'apuslisting'),
                        'default' => 1
                    ),
                    array(
                        'id' => 'listing_review_enable_report',
                        'type' => 'switch',
                        'title' => esc_html__('Enable report review', 'apuslisting'),
                        'default' => 1,
                        'description' => esc_html__('Only user loged in can report review', 'apuslisting'),
                    ),
                )
            );
            // sections after listings
            $sections = apply_filters( 'apuslisting_redux_config_sections_after_listing', array() );
            if ( !empty($sections) ) {
                foreach ($sections as $section) {
                    $this->sections[] = $section;
                }
            }
            
            // Listing Map Settings
            $this->sections[] = array(
                'title' => esc_html__('Listing Map Settings', 'apuslisting'),
                'fields' => array(
                    // google map style
                    array(
                        'id' => 'listing_map_style_type',
                        'type' => 'select',
                        'title' => esc_html__('Custom Style Type', 'apuslisting'),
                        'options' => array(
                            'default' => esc_html__('Default', 'apuslisting'),
                            'mapbox' => esc_html__('MapBox', 'apuslisting')
                        ),
                        'default' => 'default'
                    ),
                    array(
                        'id' => 'listing_map_custom_style',
                        'type' => 'textarea',
                        'title' => esc_html__('Custom Style', 'apuslisting'),
                        'description' => wp_kses( __('<a href="//snazzymaps.com/">Get custom style</a> and paste it below. If there is nothing added, we will fallback to the Google Maps service.', 'apuslisting'), array('a' => array('href' => array()))),
                        'required' => array('listing_map_style_type', '=', 'default'),
                    ),
                    array(
                        'id' => 'listing_mapbox_token',
                        'type' => 'text',
                        'title' => esc_html__('Mapbox Token', 'apuslisting'),
                        'description' => wp_kses( __('<a href="//www.mapbox.com/help/create-api-access-token/">Get a FREE token</a> and paste it below. If there is nothing added, we will fallback to the Google Maps service.', 'apuslisting'), array('a' => array('href' => array()))),
                        'required' => array('listing_map_style_type', '=', 'mapbox'),
                    ),
                    array(
                        'id' => 'listing_mapbox_style',
                        'type' => 'image_select',
                        'compiler' => true,
                        'title' => esc_html__('MapBox Style', 'apuslisting'),
                        'description' => esc_html__('Custom map styles works only if you have set a valid Mapbox API token in the field above.', 'apuslisting'),
                        'options' => array(
                            'mapbox.streets-basic' => array(
                                'alt' => esc_html__('streets basic', 'apuslisting'),
                                'img' => get_template_directory_uri() . '/inc/assets/images/streets-basic.png'
                            ),
                            'mapbox.streets' => array(
                                'alt' => esc_html__('streets', 'apuslisting'),
                                'img' => get_template_directory_uri() . '/inc/assets/images/streets.png'
                            ),
                            'mapbox.outdoors' => array(
                                'alt' => esc_html__('outdoors', 'apuslisting'),
                                'img' => get_template_directory_uri() . '/inc/assets/images/outdoors.png'
                            ),
                            'mapbox.light' => array(
                                'alt' => esc_html__('light', 'apuslisting'),
                                'img' => get_template_directory_uri() . '/inc/assets/images/light.png'
                            ),
                            'mapbox.emerald' => array(
                                'alt' => esc_html__('emerald', 'apuslisting'),
                                'img' => get_template_directory_uri() . '/inc/assets/images/emerald.png'
                            ),

                            'mapbox.satellite' => array(
                                'alt' => esc_html__('satellite', 'apuslisting'),
                                'img' => get_template_directory_uri() . '/inc/assets/images/satellite.png'
                            ),
                            'mapbox.pencil' => array(
                                'alt' => esc_html__('pencil', 'apuslisting'),
                                'img' => get_template_directory_uri() . '/inc/assets/images/pencil.png'
                            ),
                            'mapbox.pirates' => array(
                                'alt' => esc_html__('pirates', 'apuslisting'),
                                'img' => get_template_directory_uri() . '/inc/assets/images/pirates.png'
                            ),
                        ),
                        'required' => array('listing_map_style_type', '=', 'mapbox'),
                    ),
                )
            );
            $this->sections[] = array(
                'title' => esc_html__('User Profile', 'apuslisting'),
                'fields' => array(
                    array (
                        'id' => 'profile_breadcrumb_setting',
                        'icon' => true,
                        'type' => 'info',
                        'raw' => '<h3 style="margin: 0;"> '.esc_html__('Breadcrumbs Settings', 'apuslisting').'</h3>',
                    ),
                    array(
                        'id' => 'show_profile_breadcrumbs',
                        'type' => 'switch',
                        'title' => esc_html__('Breadcrumbs', 'apuslisting'),
                        'default' => 1
                    ),
                    array (
                        'title' => esc_html__('Breadcrumbs Background Color', 'apuslisting'),
                        'subtitle' => '<em>'.esc_html__('The breadcrumbs background color of the site.', 'apuslisting').'</em>',
                        'id' => 'profile_breadcrumb_color',
                        'type' => 'color',
                        'transparent' => false,
                    ),
                    array(
                        'id' => 'profile_breadcrumb_image',
                        'type' => 'media',
                        'title' => esc_html__('Breadcrumbs Background', 'apuslisting'),
                        'subtitle' => esc_html__('Upload a .jpg or .png image that will be your breadcrumbs.', 'apuslisting'),
                    ),
                    array (
                        'id' => 'profile_setting',
                        'icon' => true,
                        'type' => 'info',
                        'raw' => '<h3 style="margin: 0;"> '.esc_html__('General Settings', 'apuslisting').'</h3>',
                    ),
                    array(
                        'id' => 'user_profile_listing_number',
                        'type' => 'text',
                        'title' => esc_html__('Number of Listings Per Page', 'apuslisting'),
                        'default' => 25,
                        'min' => '1',
                        'step' => '1',
                        'max' => '100',
                        'type' => 'slider'
                    ),
                    array(
                        'id' => 'user_profile_favorite_number',
                        'type' => 'text',
                        'title' => esc_html__('Number of Favorites Per Page', 'apuslisting'),
                        'default' => 25,
                        'min' => '1',
                        'step' => '1',
                        'max' => '100',
                        'type' => 'slider'
                    ),
                    array(
                        'id' => 'user_profile_reviews_number',
                        'type' => 'text',
                        'title' => esc_html__('Number of Reviews Per Page', 'apuslisting'),
                        'default' => 25,
                        'min' => '1',
                        'step' => '1',
                        'max' => '100',
                        'type' => 'slider'
                    ),
                    array(
                        'id' => 'user_profile_follow_number',
                        'type' => 'text',
                        'title' => esc_html__('Number of Following/Follower Per Page', 'apuslisting'),
                        'default' => 25,
                        'min' => '1',
                        'step' => '1',
                        'max' => '100',
                        'type' => 'slider'
                    ),
                )
            );
            // Email Template
            $email_template_fields = apply_filters( 'apuslisting_email_template_fields', array(
                array(
                    'id' => 'comment_report_email',
                    'icon' => true,
                    'type' => 'info',
                    'raw' => '<h3 style="margin: 0;"> '.esc_html__('Comment Report Email Templates', 'apuslisting').'</h3>',
                ),
                array(
                    'id' => 'comment_report_email_subject',
                    'type' => 'textarea',
                    'title' => esc_html__('Email Subject', 'apuslisting'),
                    'default' => 'Report Comment'
                ),
                array(
                    'id' => 'comment_report_email_message',
                    'type' => 'editor',
                    'title' => esc_html__('Email Body', 'apuslisting'),
                    'description' => esc_html__('Variables: ', 'apuslisting').'{comment_link}, {comment_msg}',
                )
            ));
            $this->sections[] = array(
                'title' => esc_html__('Email Templates', 'apuslisting'),
                'fields' => $email_template_fields
            );
            // Woocommerce
            $this->sections[] = array(
                'icon' => 'el el-shopping-cart',
                'title' => esc_html__('Woocommerce', 'apuslisting'),
                'fields' => array(
                    array(
                        'id' => 'show_product_breadcrumbs',
                        'type' => 'switch',
                        'title' => esc_html__('Breadcrumbs', 'apuslisting'),
                        'default' => 1
                    ),
                    array (
                        'title' => esc_html__('Breadcrumbs Background Color', 'apuslisting'),
                        'subtitle' => '<em>'.esc_html__('The breadcrumbs background color of the site.', 'apuslisting').'</em>',
                        'id' => 'woo_breadcrumb_color',
                        'type' => 'color',
                        'transparent' => false,
                    ),
                    array(
                        'id' => 'woo_breadcrumb_image',
                        'type' => 'media',
                        'title' => esc_html__('Breadcrumbs Background', 'apuslisting'),
                        'subtitle' => esc_html__('Upload a .jpg or .png image that will be your breadcrumbs.', 'apuslisting'),
                    ),
                )
            );
            // Archive settings
            $this->sections[] = array(
                'subsection' => true,
                'title' => esc_html__('Product Archives', 'apuslisting'),
                'fields' => array(
                    array(
                        'id' => 'product_archive_layout',
                        'type' => 'image_select',
                        'compiler' => true,
                        'title' => esc_html__('Archive Product Layout', 'apuslisting'),
                        'subtitle' => esc_html__('Select the layout you want to apply on your archive product page.', 'apuslisting'),
                        'options' => array(
                            'main' => array(
                                'title' => esc_html__('Main Content', 'apuslisting'),
                                'alt' => esc_html__('Main Content', 'apuslisting'),
                                'img' => get_template_directory_uri() . '/inc/assets/images/screen1.png'
                            ),
                            'left-main' => array(
                                'title' => esc_html__('Left Sidebar - Main Content', 'apuslisting'),
                                'alt' => esc_html__('Left Sidebar - Main Content', 'apuslisting'),
                                'img' => get_template_directory_uri() . '/inc/assets/images/screen2.png'
                            ),
                            'main-right' => array(
                                'title' => esc_html__('Main Content - Right Sidebar', 'apuslisting'),
                                'alt' => esc_html__('Main Content - Right Sidebar', 'apuslisting'),
                                'img' => get_template_directory_uri() . '/inc/assets/images/screen3.png'
                            ),
                            'left-main-right' => array(
                                'title' => esc_html__('Left Sidebar - Main Content - Right Sidebar', 'apuslisting'),
                                'alt' => esc_html__('Left Sidebar - Main Content - Right Sidebar', 'apuslisting'),
                                'img' => get_template_directory_uri() . '/inc/assets/images/screen4.png'
                            ),
                        ),
                        'default' => 'left-main'
                    ),
                    array(
                        'id' => 'product_archive_fullwidth',
                        'type' => 'switch',
                        'title' => esc_html__('Is Full Width?', 'apuslisting'),
                        'default' => false
                    ),
                    array(
                        'id' => 'product_archive_filter_sidebar',
                        'type' => 'select',
                        'title' => esc_html__('Filter Sidebar', 'apuslisting'),
                        'subtitle' => esc_html__('Show filter sidebar when shop only show Main Content.', 'apuslisting'),
                        'options' => array(
                            'none' => esc_html__('Do not show', 'apuslisting'),
                            'right' => esc_html__('Right', 'apuslisting'),
                            'top' => esc_html__('Categories + Sidebar in Top', 'apuslisting'),
                        ),
                        'required' => array('product_archive_layout', '=', 'main'),
                        'default' => 'none'
                    ),
                    array(
                        'id' => 'product_archive_left_sidebar',
                        'type' => 'select',
                        'title' => esc_html__('Archive Left Sidebar', 'apuslisting'),
                        'subtitle' => esc_html__('Choose a sidebar for left sidebar.', 'apuslisting'),
                        'options' => $sidebars
                    ),
                    array(
                        'id' => 'product_archive_right_sidebar',
                        'type' => 'select',
                        'title' => esc_html__('Archive Right Sidebar', 'apuslisting'),
                        'subtitle' => esc_html__('Choose a sidebar for right sidebar.', 'apuslisting'),
                        'options' => $sidebars
                    ),
                    array(
                        'id' => 'product_display_mode',
                        'type' => 'select',
                        'title' => esc_html__('Display Mode', 'apuslisting'),
                        'subtitle' => esc_html__('Choose a default layout archive product.', 'apuslisting'),
                        'options' => array('grid' => esc_html__('Grid', 'apuslisting'), 'list' => esc_html__('List', 'apuslisting')),
                        'default' => 'grid'
                    ),
                    array(
                        'id' => 'number_products_per_page',
                        'type' => 'text',
                        'title' => esc_html__('Number of Products Per Page', 'apuslisting'),
                        'default' => 12,
                        'min' => '1',
                        'step' => '1',
                        'max' => '100',
                        'type' => 'slider'
                    ),
                    array(
                        'id' => 'product_columns',
                        'type' => 'select',
                        'title' => esc_html__('Product Columns', 'apuslisting'),
                        'options' => $columns,
                        'default' => 4
                    ),
                    array(
                        'id' => 'show_quickview',
                        'type' => 'switch',
                        'title' => esc_html__('Show Quick View', 'apuslisting'),
                        'default' => 1
                    ),
                    array(
                        'id' => 'show_swap_image',
                        'type' => 'switch',
                        'title' => esc_html__('Show Second Image (Hover)', 'apuslisting'),
                        'default' => 1
                    ),
                )
            );
            // Product Page
            $this->sections[] = array(
                'subsection' => true,
                'title' => esc_html__('Single Product', 'apuslisting'),
                'fields' => array(
                    array(
                        'id' => 'product_single_layout',
                        'type' => 'image_select',
                        'compiler' => true,
                        'title' => esc_html__('Single Product Layout', 'apuslisting'),
                        'subtitle' => esc_html__('Select the layout you want to apply on your Single Product Page.', 'apuslisting'),
                        'options' => array(
                            'main' => array(
                                'title' => esc_html__('Main Only', 'apuslisting'),
                                'alt' => esc_html__('Main Only', 'apuslisting'),
                                'img' => get_template_directory_uri() . '/inc/assets/images/screen1.png'
                            ),
                            'left-main' => array(
                                'title' => esc_html__('Left - Main Sidebar', 'apuslisting'),
                                'alt' => esc_html__('Left - Main Sidebar', 'apuslisting'),
                                'img' => get_template_directory_uri() . '/inc/assets/images/screen2.png'
                            ),
                            'main-right' => array(
                                'title' => esc_html__('Main - Right Sidebar', 'apuslisting'),
                                'alt' => esc_html__('Main - Right Sidebar', 'apuslisting'),
                                'img' => get_template_directory_uri() . '/inc/assets/images/screen3.png'
                            ),
                            'left-main-right' => array(
                                'title' => esc_html__('Left - Main - Right Sidebar', 'apuslisting'),
                                'alt' => esc_html__('Left - Main - Right Sidebar', 'apuslisting'),
                                'img' => get_template_directory_uri() . '/inc/assets/images/screen4.png'
                            ),
                        ),
                        'default' => 'left-main'
                    ),
                    array(
                        'id' => 'product_single_fullwidth',
                        'type' => 'switch',
                        'title' => esc_html__('Is Full Width?', 'apuslisting'),
                        'default' => false
                    ),
                    array(
                        'id' => 'product_single_left_sidebar',
                        'type' => 'select',
                        'title' => esc_html__('Single Product Left Sidebar', 'apuslisting'),
                        'subtitle' => esc_html__('Choose a sidebar for left sidebar.', 'apuslisting'),
                        'options' => $sidebars
                    ),
                    array(
                        'id' => 'product_single_right_sidebar',
                        'type' => 'select',
                        'title' => esc_html__('Single Product Right Sidebar', 'apuslisting'),
                        'subtitle' => esc_html__('Choose a sidebar for right sidebar.', 'apuslisting'),
                        'options' => $sidebars
                    ),
                    array(
                        'id' => 'show_product_social_share',
                        'type' => 'switch',
                        'title' => esc_html__('Show Social Share', 'apuslisting'),
                        'default' => 1
                    ),
                    array(
                        'id' => 'show_product_review_tab',
                        'type' => 'switch',
                        'title' => esc_html__('Show Product Review Tab', 'apuslisting'),
                        'default' => 1
                    ),
                    array(
                        'id' => 'show_product_releated',
                        'type' => 'switch',
                        'title' => esc_html__('Show Products Releated', 'apuslisting'),
                        'default' => 1
                    ),
                    array(
                        'id' => 'show_product_upsells',
                        'type' => 'switch',
                        'title' => esc_html__('Show Products upsells', 'apuslisting'),
                        'default' => 1
                    ),
                    array(
                        'id' => 'number_product_releated',
                        'title' => esc_html__('Number of related/upsells products to show', 'apuslisting'),
                        'default' => 4,
                        'min' => '1',
                        'step' => '1',
                        'max' => '20',
                        'type' => 'slider'
                    ),
                    array(
                        'id' => 'releated_product_columns',
                        'type' => 'select',
                        'title' => esc_html__('Releated Products Columns', 'apuslisting'),
                        'options' => $columns,
                        'default' => 4
                    ),

                )
            );
            // 404 page
            $this->sections[] = array(
                'title' => esc_html__('404 Page', 'apuslisting'),
                'fields' => array(
                    array(
                        'id' => '404_title',
                        'type' => 'text',
                        'title' => esc_html__('Title', 'apuslisting'),
                        'default' => '404'
                    ),
                    array(
                        'id' => '404_subtitle',
                        'type' => 'text',
                        'title' => esc_html__('SubTitle', 'apuslisting'),
                        'default' => 'OHH! PAGE NOT FOUND'
                    ),
                    array(
                        'id' => '404_description',
                        'type' => 'textarea',
                        'title' => esc_html__('Description', 'apuslisting'),
                        'default' => 'It seems we can not find what you are looking for. Perhaps searching can help or go back to'
                    ),
                )
            );
            // Style
            $this->sections[] = array(
                'icon' => 'el el-icon-css',
                'title' => esc_html__('Style', 'apuslisting'),
                'fields' => array(
                    array (
                        'title' => esc_html__('Main Theme Color', 'apuslisting'),
                        'subtitle' => '<em>'.esc_html__('The main color of the site.', 'apuslisting').'</em>',
                        'id' => 'main_color',
                        'type' => 'color',
                        'transparent' => false,
                    ),
                    array (
                        'title' => esc_html__('Second Theme Color', 'apuslisting'),
                        'subtitle' => '<em>'.esc_html__('The main color of the site.', 'apuslisting').'</em>',
                        'id' => 'second_color',
                        'type' => 'color',
                        'transparent' => false,
                    ),
                    array (
                        'title' => esc_html__('Button Theme Color', 'apuslisting'),
                        'subtitle' => '<em>'.esc_html__('The main color of the site.', 'apuslisting').'</em>',
                        'id' => 'button_main_color',
                        'type' => 'color',
                        'transparent' => false,
                    ),
                    array (
                        'title' => esc_html__('Button Theme Color Hover', 'apuslisting'),
                        'subtitle' => '<em>'.esc_html__('The main color of the site.', 'apuslisting').'</em>',
                        'id' => 'button_main_color_hover',
                        'type' => 'color',
                        'transparent' => false,
                    ),
                    array (
                        'title' => esc_html__('Button Second Theme Color', 'apuslisting'),
                        'subtitle' => '<em>'.esc_html__('The main color of the site.', 'apuslisting').'</em>',
                        'id' => 'button_second_color',
                        'type' => 'color',
                        'transparent' => false,
                    ),
                    array (
                        'title' => esc_html__('Button Second Theme Color Hover', 'apuslisting'),
                        'subtitle' => '<em>'.esc_html__('The main color of the site.', 'apuslisting').'</em>',
                        'id' => 'button_second_color_hover',
                        'type' => 'color',
                        'transparent' => false,
                    ),
                )
            );
            $this->sections[] = array(
                'subsection' => true,
                'title' => esc_html__('Typography', 'apuslisting'),
                'fields' => array(
                    array(
                        'title'    => esc_html__('Font Source', 'apuslisting'),
                        'subtitle' => '<em>'.esc_html__('Choose the Font Source', 'apuslisting').'</em>',
                        'id'       => 'font_source',
                        'type'     => 'radio',
                        'options'  => array(
                            '1' => 'Standard + Google Webfonts',
                            '2' => 'Google Custom'
                        ),
                        'default' => '1'
                    ),
                    array(
                        'id'=>'font_google_code',
                        'type' => 'text',
                        'title' => esc_html__('Google Code', 'apuslisting'), 
                        'subtitle' => '<em>'.esc_html__('Paste the provided Google Code', 'apuslisting').'</em>',
                        'required' => array('font_source','=','2')
                    ),
                    array (
                        'id' => 'main_font_info',
                        'icon' => true,
                        'type' => 'info',
                        'raw' => '<h3 style="margin: 0;"> '.esc_html__('Main Font', 'apuslisting').'</h3>',
                    ),
                    // Standard + Google Webfonts
                    array (
                        'title' => esc_html__('Font Face', 'apuslisting'),
                        'subtitle' => '<em>'.esc_html__('Pick the Main Font for your site.', 'apuslisting').'</em>',
                        'id' => 'main_font',
                        'type' => 'typography',
                        'line-height' => false,
                        'text-align' => false,
                        'font-style' => false,
                        'font-weight' => false,
                        'all_styles'=> true,
                        'font-size' => false,
                        'color' => false,
                        'default' => array (
                            'font-family' => 'Montserrat',
                            'subsets' => '',
                        ),
                        'required' => array('font_source','=','1')
                    ),
                    
                    // Google Custom                        
                    array (
                        'title' => esc_html__('Google Font Face', 'apuslisting'),
                        'subtitle' => '<em>'.esc_html__('Enter your Google Font Name for the theme\'s Main Typography', 'apuslisting').'</em>',
                        'desc' => esc_html__('e.g.: open sans', 'apuslisting'),
                        'id' => 'main_google_font_face',
                        'type' => 'text',
                        'required' => array('font_source','=','2')
                    ),

                    array (
                        'id' => 'secondary_font_info',
                        'icon' => true,
                        'type' => 'info',
                        'raw' => '<h3 style="margin: 0;"> '.esc_html__(' Secondary Font', 'apuslisting').'</h3>',
                    ),
                    
                    // Standard + Google Webfonts
                    array (
                        'title' => esc_html__('Font Face', 'apuslisting'),
                        'subtitle' => '<em>'.esc_html__('Pick the Secondary Font for your site.', 'apuslisting').'</em>',
                        'id' => 'secondary_font',
                        'type' => 'typography',
                        'line-height' => false,
                        'text-align' => false,
                        'font-style' => false,
                        'font-weight' => false,
                        'all_styles'=> true,
                        'font-size' => false,
                        'color' => false,
                        'required' => array('font_source','=','1')
                        
                    ),
                    
                    // Google Custom                        
                    array (
                        'title' => esc_html__('Google Font Face', 'apuslisting'),
                        'subtitle' => '<em>'.esc_html__('Enter your Google Font Name for the theme\'s Secondary Typography', 'apuslisting').'</em>',
                        'desc' => esc_html__('e.g.: open sans', 'apuslisting'),
                        'id' => 'secondary_google_font_face',
                        'type' => 'text',
                        'required' => array('font_source','=','2')
                    ),
                )
            );
            $this->sections[] = array(
                'subsection' => true,
                'title' => esc_html__('Header', 'apuslisting'),
                'fields' => array(
                    array(
                        'id'=>'header_bg',
                        'type' => 'background',
                        'title' => esc_html__('Background', 'apuslisting'),
                        'default' => array(
                            'background-color' => ''
                        )
                    ),
                    array(
                        'title' => esc_html__('Text Color', 'apuslisting'),
                        'id' => 'header_text_color',
                        'type' => 'color',
                        'transparent' => false,
                        'default' => '',
                    ),
                    array(
                        'title' => esc_html__('Link Color', 'apuslisting'),
                        'id' => 'header_link_color',
                        'type' => 'color',
                        'transparent' => false,
                        'default' => '',
                    ),
                    array(
                        'title' => esc_html__('Link Color Active', 'apuslisting'),
                        'id' => 'header_link_color_active',
                        'type' => 'color',
                        'transparent' => false,
                        'default' => '',
                    ),
                )
            );
            $this->sections[] = array(
                'subsection' => true,
                'title' => esc_html__('Main Menu', 'apuslisting'),
                'fields' => array(
                    array(
                        'title' => esc_html__('Link Color', 'apuslisting'),
                        'id' => 'main_menu_link_color',
                        'type' => 'color',
                        'transparent' => false,
                        'default' => '',
                    ),
                    array(
                        'title' => esc_html__('Link Color Active', 'apuslisting'),
                        'id' => 'main_menu_link_color_active',
                        'type' => 'color',
                        'transparent' => false,
                        'default' => '',
                    ),
                )
            );
            $this->sections[] = array(
                'subsection' => true,
                'title' => esc_html__('Footer', 'apuslisting'),
                'fields' => array(
                    array(
                        'id'=>'footer_bg',
                        'type' => 'background',
                        'title' => esc_html__('Background', 'apuslisting'),
                        'default' => array(
                            'background-color' => ''
                        )
                    ),
                    array(
                        'title' => esc_html__('Heading Color', 'apuslisting'),
                        'id' => 'footer_heading_color',
                        'type' => 'color',
                        'transparent' => false,
                        'default' => '',
                    ),
                    array(
                        'title' => esc_html__('Text Color', 'apuslisting'),
                        'id' => 'footer_text_color',
                        'type' => 'color',
                        'transparent' => false,
                        'default' => '',
                    ),
                    array(
                        'title' => esc_html__('Link Color', 'apuslisting'),
                        'id' => 'footer_link_color',
                        'type' => 'color',
                        'transparent' => false,
                        'default' => '',
                    ),
                    array(
                        'title' => esc_html__('Link Color Hover', 'apuslisting'),
                        'id' => 'footer_link_color_hover',
                        'type' => 'color',
                        'transparent' => false,
                        'default' => '',
                    ),
                )
            );
            
            $this->sections[] = array(
                'subsection' => true,
                'title' => esc_html__('Copyright', 'apuslisting'),
                'fields' => array(
                    array(
                        'id'=>'copyright_bg',
                        'type' => 'background',
                        'title' => esc_html__('Background', 'apuslisting'),
                        'default' => array(
                            'background-color' => ''
                        )
                    ),
                    array(
                        'title' => esc_html__('Text Color', 'apuslisting'),
                        'id' => 'copyright_text_color',
                        'type' => 'color',
                        'transparent' => false,
                        'default' => '',
                    ),
                    array(
                        'title' => esc_html__('Link Color', 'apuslisting'),
                        'id' => 'copyright_link_color',
                        'type' => 'color',
                        'transparent' => false,
                        'default' => '',
                    ),
                    array(
                        'title' => esc_html__('Link Color Hover', 'apuslisting'),
                        'id' => 'copyright_link_color_hover',
                        'type' => 'color',
                        'transparent' => false,
                        'default' => '',
                    ),
                )
            );

            // Social Media
            $this->sections[] = array(
                'icon' => 'el el-file',
                'title' => esc_html__('Social Media', 'apuslisting'),
                'fields' => array(
                    array(
                        'id' => 'facebook_share',
                        'type' => 'switch',
                        'title' => esc_html__('Enable Facebook Share', 'apuslisting'),
                        'default' => 1
                    ),
                    array(
                        'id' => 'twitter_share',
                        'type' => 'switch',
                        'title' => esc_html__('Enable twitter Share', 'apuslisting'),
                        'default' => 1
                    ),
                    array(
                        'id' => 'linkedin_share',
                        'type' => 'switch',
                        'title' => esc_html__('Enable linkedin Share', 'apuslisting'),
                        'default' => 1
                    ),
                    array(
                        'id' => 'tumblr_share',
                        'type' => 'switch',
                        'title' => esc_html__('Enable tumblr Share', 'apuslisting'),
                        'default' => 1
                    ),
                    array(
                        'id' => 'google_share',
                        'type' => 'switch',
                        'title' => esc_html__('Enable google plus Share', 'apuslisting'),
                        'default' => 1
                    ),
                    array(
                        'id' => 'pinterest_share',
                        'type' => 'switch',
                        'title' => esc_html__('Enable pinterest Share', 'apuslisting'),
                        'default' => 1
                    )
                )
            );
            // Custom Code
            $this->sections[] = array(
                'icon' => 'el-icon-css',
                'title' => esc_html__('Custom CSS/JS', 'apuslisting'),
                'fields' => array(
                    array (
                        'title' => esc_html__('Custom CSS', 'apuslisting'),
                        'subtitle' => esc_html__('<em>Paste your custom CSS code here.</em>', 'apuslisting'),
                        'id' => 'custom_css',
                        'type' => 'ace_editor',
                        'mode' => 'css',
                    ),
                    
                    array (
                        'title' => esc_html__('Custom JavaScript Code', 'apuslisting'),
                        'subtitle' => esc_html__('<em>Here is the place to paste your Google Analytics code or any other JS code you might want to add to be loaded in your website.</em>', 'apuslisting'),
                        'id' => 'custom_js',
                        'type' => 'ace_editor',
                        'mode' => 'javascript',
                    ),
                )
            );
            $this->sections[] = array(
                'title' => esc_html__('Import / Export', 'apuslisting'),
                'desc' => esc_html__('Import and Export your Redux Framework settings from file, text or URL.', 'apuslisting'),
                'icon' => 'el-icon-refresh',
                'fields' => array(
                    array(
                        'id' => 'opt-import-export',
                        'type' => 'import_export',
                        'title' => 'Import Export',
                        'subtitle' => 'Save and restore your Redux options',
                        'full_width' => false,
                    ),
                ),
            );

            $this->sections[] = array(
                'type' => 'divide',
            );
        }

        /**
         * All the possible arguments for Redux.
         * For full documentation on arguments, please refer to: https://github.com/ReduxFramework/ReduxFramework/wiki/Arguments
         * */
        public function setArguments()
        {

            $theme = wp_get_theme(); // For use with some settings. Not necessary.

            $preset = apuslisting_get_demo_preset();
            
            $this->args = array(
                // TYPICAL -> Change these values as you need/desire
                'opt_name' => 'apuslisting_theme_options'.$preset,
                // This is where your data is stored in the database and also becomes your global variable name.
                'display_name' => $theme->get('Name'),
                // Name that appears at the top of your panel
                'display_version' => $theme->get('Version'),
                // Version that appears at the top of your panel
                'menu_type' => 'menu',
                //Specify if the admin menu should appear or not. Options: menu or submenu (Under appearance only)
                'allow_sub_menu' => true,
                // Show the sections below the admin menu item or not
                'menu_title' => esc_html__('Apuslisting Options', 'apuslisting'),
                'page_title' => esc_html__('Apuslisting Options', 'apuslisting'),

                // You will need to generate a Google API key to use this feature.
                // Please visit: https://developers.google.com/fonts/docs/developer_api#Auth
                'google_api_key' => '',
                // Set it you want google fonts to update weekly. A google_api_key value is required.
                'google_update_weekly' => false,
                // Must be defined to add google fonts to the typography module
                'async_typography' => true,
                // Use a asynchronous font on the front end or font string
                //'disable_google_fonts_link' => true,                    // Disable this in case you want to create your own google fonts loader
                'admin_bar' => true,
                // Show the panel pages on the admin bar
                'admin_bar_icon' => 'dashicons-portfolio',
                // Choose an icon for the admin bar menu
                'admin_bar_priority' => 50,
                // Choose an priority for the admin bar menu
                'global_variable' => 'apus_options',
                // Set a different name for your global variable other than the opt_name
                'dev_mode' => false,
                // Show the time the page took to load, etc
                'update_notice' => true,
                // If dev_mode is enabled, will notify developer of updated versions available in the GitHub Repo
                'customizer' => true,
                // Enable basic customizer support
                //'open_expanded'     => true,                    // Allow you to start the panel in an expanded way initially.
                //'disable_save_warn' => true,                    // Disable the save warning when a user changes a field

                // OPTIONAL -> Give you extra features
                'page_priority' => null,
                // Order where the menu appears in the admin area. If there is any conflict, something will not show. Warning.
                'page_parent' => 'themes.php',
                // For a full list of options, visit: http://codex.wordpress.org/Function_Reference/add_submenu_page#Parameters
                'page_permissions' => 'manage_options',
                // Permissions needed to access the options panel.
                'menu_icon' => '',
                // Specify a custom URL to an icon
                'last_tab' => '',
                // Force your panel to always open to a specific tab (by id)
                'page_icon' => 'icon-themes',
                // Icon displayed in the admin panel next to your menu_title
                'page_slug' => '_options',
                // Page slug used to denote the panel
                'save_defaults' => true,
                // On load save the defaults to DB before user clicks save or not
                'default_show' => false,
                // If true, shows the default value next to each field that is not the default value.
                'default_mark' => '',
                // What to print by the field's title if the value shown is default. Suggested: *
                'show_import_export' => true,
                // Shows the Import/Export panel when not used as a field.

                // CAREFUL -> These options are for advanced use only
                'transient_time' => 60 * MINUTE_IN_SECONDS,
                'output' => true,
                // Global shut-off for dynamic CSS output by the framework. Will also disable google fonts output
                'output_tag' => true,
                // Allows dynamic CSS to be generated for customizer and google fonts, but stops the dynamic CSS from going to the head
                // 'footer_credit'     => '',                   // Disable the footer credit of Redux. Please leave if you can help it.

                // FUTURE -> Not in use yet, but reserved or partially implemented. Use at your own risk.
                'database' => '',
                // possible: options, theme_mods, theme_mods_expanded, transient. Not fully functional, warning!
                'system_info' => false,
                // REMOVE

                // HINTS
                'hints' => array(
                    'icon' => 'icon-question-sign',
                    'icon_position' => 'right',
                    'icon_color' => 'lightgray',
                    'icon_size' => 'normal',
                    'tip_style' => array(
                        'color' => 'light',
                        'shadow' => true,
                        'rounded' => false,
                        'style' => '',
                    ),
                    'tip_position' => array(
                        'my' => 'top left',
                        'at' => 'bottom right',
                    ),
                    'tip_effect' => array(
                        'show' => array(
                            'effect' => 'slide',
                            'duration' => '500',
                            'event' => 'mouseover',
                        ),
                        'hide' => array(
                            'effect' => 'slide',
                            'duration' => '500',
                            'event' => 'click mouseleave',
                        ),
                    ),
                )
            );
            $this->args['intro_text'] = '';

            // Add content after the form.
            $this->args['footer_text'] = '';
            return $this->args;
        }

    }

    global $reduxConfig;
    $reduxConfig = new Apuslisting_Redux_Framework_Config();
}
