<?php

function apuslisting_woo_pre_get_posts( $q ) {
    if ( ! $q->is_main_query() ) {
        return;
    }
    // Fix for verbose page rules
    if ( $q->is_archive && ((isset($q->query_vars['post_type']) && $q->query_vars['post_type'] == 'product') || isset($q->query_vars['product_cat'])) && !$q->is_admin ) {
        
        $q->set( 'meta_query', array(
            'relation' => 'OR',
            array(
               'key' => '_ywsbs_subscription',
               'value' => 'yes',
               'compare' => '!=',
            ),
            array( //if no date has been added show these posts too
                'key' => '_ywsbs_subscription',
                'value' => 'yes',
                'compare' => 'NOT EXISTS'
            )
        ));
    }
}
add_action( 'pre_get_posts', 'apuslisting_woo_pre_get_posts', 10 );


function apuslisting_add_custom_fields_for_single_products(){
    global $thepostid;

    $_ywsbs_number_listings = get_post_meta( $thepostid, '_ywsbs_number_listings', true );
    ?>
    
    <div class="options_group show_if_simple">
        
        <p class="form-field ywsbs_max_length">
            <label for="_ywsbs_number_listings"><?php esc_html_e( 'Max Listings:', 'apuslisting' ); ?></label>
            <input type="text" class="short" name="_ywsbs_number_listings" id="_ywsbs_number_listings" value="<?php echo esc_attr( $_ywsbs_number_listings ); ?>" style="float: left; width:15%; " />
            <span class="description"><?php echo esc_html__( 'Max number listings customer can submit.', 'apuslisting' ); ?></span>
        </p>

    </div>
    <?php
}
add_action( 'woocommerce_product_options_general_product_data', 'apuslisting_add_custom_fields_for_single_products' );

function apuslisting_save_custom_fields_for_single_products( $post_id, $post ){

    if ( isset( $_POST['_ywsbs_number_listings'] ) ){
        update_post_meta( $post_id, '_ywsbs_number_listings',  $_POST['_ywsbs_number_listings'] );
    }

}
add_action( 'woocommerce_process_product_meta', 'apuslisting_save_custom_fields_for_single_products', 10, 2 );


$yith = YITH_WC_Subscription::get_instance();
remove_filter('woocommerce_get_price_html', array($yith, 'change_price_html'), 10, 2);

$subscription = YWSBS_Subscription_Order::get_instance();
remove_action('woocommerce_order_status_processing', array($subscription, 'payment_complete'));
remove_action('woocommerce_checkout_order_processed', array($subscription, 'check_order_for_subscription'), 100, 2);
add_action('woocommerce_checkout_order_processed', 'apuslisting_checkout_update_order_meta', 100, 2);

function apuslisting_checkout_update_order_meta($order_id, $posted) {
    $subscription = YWSBS_Subscription_Order::get_instance();
    $order = wc_get_order( $order_id );
    $order_items = $order->get_items();

    if( empty( $order_items)){
        return;
    }

    foreach ( $order_items as $key => $order_item  ) {

        $product_id = $order_item['product_id'];
        $variation_id = ( isset( $order_item['variation_id'] ) && !empty( $order_item['variation_id'] ) ) ? $order_item['variation_id'] : '';
        $shippings = $subscription->subscription_meta['subscriptions_shippings'];

        $shipping_method = '';
        if( YITH_WC_Subscription()->is_subscription( $product_id ) ){

            foreach ( $shippings as $ship ) {
                if( in_array( $product_id, $ship['ids'])){
                    $shipping_method[] = $ship;
                }
            }

            $args = array(
                'product_id'             => $order_item['product_id'],
                'variation_id'           => $variation_id,
                'product_name'           => $order_item['name'],

                'user_id'                => get_post_meta( $order_id, '_customer_user', true ),

                'customer_ip_address'    => get_post_meta( $order_id, '_customer_ip_address', true ),
                'customer_user_agent'    => get_post_meta( $order_id, '_customer_user_agent', true ),

                'quantity'               => $order_item['qty'],
                'order_id'               => $order_id,
                'order_ids'              => array($order_id),
                'order_total'            => get_post_meta( $order_id, '_order_total', true ),
                'order_currency'         => get_post_meta( $order_id, '_order_currency', true ),
                'prices_include_tax'     => get_post_meta( $order_id, '_prices_include_tax', true ),

                'payment_method'         => $subscription->subscription_meta['payment_method'],
                'payment_method_title'   => $subscription->subscription_meta['payment_method_title'],
                'subscriptions_shippings'=> $shipping_method,


                'line_subtotal'          => $order_item['line_subtotal'],
                'line_total'             => $order_item['line_total'],

                'line_subtotal_tax'     => $order_item['line_subtotal_tax'],
                'line_tax'              => $order_item['line_tax'],
                'line_tax_data'          => $order_item['line_tax_data'],
                'cart_discount'         => $subscription->subscription_meta['cart_discount'],
                'cart_discount_tax'         => $subscription->subscription_meta['cart_discount_tax'],


                'price_is_per'           => get_post_meta( $product_id, '_ywsbs_price_is_per', true ),
                'price_time_option'      => get_post_meta( $product_id, '_ywsbs_price_time_option', true ),
                'max_length'             => get_post_meta( $product_id, '_ywsbs_max_length', true ),
                'number_listings'       => get_post_meta( $product_id, '_ywsbs_number_listings', true ),
                'current_number_listings' => array(),


                'billing_first_name'     => get_post_meta( $order_id, '_billing_first_name', true ),
                'billing_last_name'      => get_post_meta( $order_id, '_billing_last_name', true ),
                'billing_company'        => get_post_meta( $order_id, '_billing_company', true ),
                'billing_address_1'      => get_post_meta( $order_id, '_billing_address_1', true ),
                'billing_address_2'      => get_post_meta( $order_id, '_billing_address_2', true ),
                'billing_city'           => get_post_meta( $order_id, '_billing_city', true ),
                'billing_state'          => get_post_meta( $order_id, '_billing_state', true ),
                'billing_postcode'       => get_post_meta( $order_id, '_billing_postcode', true ),
                'billing_country'        => get_post_meta( $order_id, '_billing_country', true ),
                'billing_email'          => get_post_meta( $order_id, '_billing_email', true ),
                'billing_phone'          => get_post_meta( $order_id, '_billing_phone', true ),

                'shipping_first_name'    => get_post_meta( $order_id, '_shipping_first_name', true ),
                'shipping_last_name'     => get_post_meta( $order_id, '_shipping_last_name', true ),
                'shipping_company'       => get_post_meta( $order_id, '_shipping_company', true ),
                'shipping_address_1'     => get_post_meta( $order_id, '_shipping_address_1', true ),
                'shipping_address_2'     => get_post_meta( $order_id, '_shipping_address_2', true ),
                'shipping_city'          => get_post_meta( $order_id, '_shipping_city', true ),
                'shipping_state'         => get_post_meta( $order_id, '_shipping_state', true ),
                'shipping_postcode'      => get_post_meta( $order_id, '_shipping_postcode', true ),
                'shipping_country'       => get_post_meta( $order_id, '_shipping_country', true ),

            );

            $subscription = new YWSBS_Subscription( '', $args );
            $subscriptions = get_post_meta( $order_id, 'subscriptions', true);
            if ( $subscription->id ) {
                $subscription_id = $subscription->id;
                $subscriptions[] = $subscription_id;
                update_post_meta( $order_id, 'subscriptions', $subscriptions );
            }
        }
    }
    
}


function apuslisting_update_submit_listing($post_ID, $post, $update) {
    if ($post->post_type == 'job_listing') {
        $user_id = get_current_user_id();
        $checked = apuslisting_check_submit();

        if ($checked) {
            $subs = apuslisting_get_subscribes_by_user();
            $current_number_listings = get_post_meta( $subs->ID, '_current_number_listings', true );
            if (empty($current_number_listings) || !is_array($current_number_listings)) {
                $current_number_listings = array();
            }
            if (!empty($current_number_listings) && isset($current_number_listings[$post_ID])) {
                $current_number_listings[$post_ID] = $current_number_listings[$post_ID] + 1;
            } else {
                $current_number_listings[$post_ID] = 1;
            }
            update_post_meta( $subs->ID, '_current_number_listings', $current_number_listings );
        }
    }
}
add_action( 'wp_insert_post', 'apuslisting_update_submit_listing', 10, 3 );

add_action('woocommerce_order_status_processing', 'apuslisting_update_submit_listing_to_pending' );
add_action('woocommerce_order_status_pending', 'apuslisting_update_submit_listing_to_pending' );
add_action('woocommerce_order_status_cancelled', 'apuslisting_update_submit_listing_to_pending' );
add_action('woocommerce_order_status_failed', 'apuslisting_update_submit_listing_to_pending' );
add_action('woocommerce_order_status_on-hold', 'apuslisting_update_submit_listing_to_pending' );
add_action('woocommerce_order_status_refunded', 'apuslisting_update_submit_listing_to_pending' );

function apuslisting_update_submit_listing_to_pending($order_id) {
    $subscriptions = get_post_meta( $order_id, 'subscriptions', true);
    if( $subscriptions != '' ){
        foreach ( $subscriptions as $subscription_id  ) {
            update_post_meta( $subscription_id, '_status', 'pending' );
            delete_post_meta( $subscription_id, '_payed_order_list' );
        }
    }
}
